@@ -1,10 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
 from .abc import (
     Broker,
     BrokerSetup,
@@ -13,6 +6,7 @@ from .command_replies import (
     CommandReplyBroker,
 )
 from .commands import (
+    REPLY_TOPIC_CONTEXT_VAR,
     CommandBroker,
 )
 from .events import (
