@@ -3,8 +3,12 @@ from __future__ import (
 )
 
 import logging
+from contextvars import (
+    ContextVar,
+)
 from typing import (
     Any,
+    Final,
     Optional,
 )
 from uuid import (
@@ -22,6 +26,8 @@ from .abc import (
 
 logger = logging.getLogger(__name__)
 
+REPLY_TOPIC_CONTEXT_VAR: Final[ContextVar[Optional[str]]] = ContextVar("reply_topic", default=None)
+
 
 class CommandBroker(Broker):
     """Minos Command Broker Class."""
@@ -57,8 +63,11 @@ class CommandBroker(Broker):
         the command is not authenticated.
         :return: This method does not return anything.
         """
+        if reply_topic is None:
+            reply_topic = REPLY_TOPIC_CONTEXT_VAR.get()
         if reply_topic is None:
             reply_topic = self.default_reply_topic
+
         command = Command(topic, data, saga, reply_topic, user)
         logger.info(f"Sending '{command!s}'...")
         return await self.enqueue(command.topic, command.avro_bytes)
