@@ -1,5 +1,3 @@
-"""minos.networks.brokers.producers module."""
-
 from __future__ import (
     annotations,
 )
@@ -26,6 +24,7 @@ from cached_property import (
 )
 from dependency_injector.wiring import (
     Provide,
+    inject,
 )
 from psycopg2.sql import (
     SQL,
@@ -51,8 +50,7 @@ logger = logging.getLogger(__name__)
 class Producer(BrokerSetup):
     """Minos Queue Dispatcher Class."""
 
-    consumer: Consumer = Provide["consumer"]
-
+    @inject
     def __init__(
         self,
         *args,
@@ -61,7 +59,7 @@ class Producer(BrokerSetup):
         retry: int,
         records: int,
         client: Optional[AIOKafkaProducer] = None,
-        consumer: Optional[Consumer] = None,
+        consumer: Consumer = Provide["consumer"],
         **kwargs,
     ):
         super().__init__(*args, **kwargs)
@@ -70,9 +68,7 @@ class Producer(BrokerSetup):
         self.retry = retry
         self.records = records
         self._client = client
-
-        if consumer is not None:
-            self.consumer = consumer
+        self.consumer = consumer
 
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> Producer:
@@ -165,7 +161,7 @@ class Producer(BrokerSetup):
         :param row: A row containing the message information.
         :return: ``True`` if everything was fine or ``False`` otherwise.
         """
-        topic, message, action = row[1], row[2], row[4]
+        topic, message, action = row[1], row[2], row[3]
 
         # noinspection PyBroadException
         try:
@@ -209,7 +205,7 @@ _SELECT_NOT_PROCESSED_QUERY = SQL(
     "SELECT * "
     "FROM producer_queue "
     "WHERE retry < %s "
-    "ORDER BY creation_date "
+    "ORDER BY created_at "
     "LIMIT %s "
     "FOR UPDATE "
     "SKIP LOCKED"
@@ -217,7 +213,7 @@ _SELECT_NOT_PROCESSED_QUERY = SQL(
 
 _DELETE_PROCESSED_QUERY = SQL("DELETE FROM producer_queue WHERE id = %s")
 
-_UPDATE_NOT_PROCESSED_QUERY = SQL("UPDATE producer_queue SET retry = retry + 1 WHERE id = %s")
+_UPDATE_NOT_PROCESSED_QUERY = SQL("UPDATE producer_queue SET retry = retry + 1, updated_at = NOW() WHERE id = %s")
 
 _LISTEN_QUERY = SQL("LISTEN producer_queue")
 
