@@ -1,5 +1,3 @@
-"""minos.networks.handlers.command_replies.handlers module."""
-
 from __future__ import (
     annotations,
 )
@@ -7,11 +5,11 @@ from __future__ import (
 import logging
 from typing import (
     Any,
-    NoReturn,
 )
 
 from dependency_injector.wiring import (
     Provide,
+    inject,
 )
 
 from minos.common import (
@@ -35,20 +33,19 @@ class CommandReplyHandler(Handler):
 
     ENTRY_MODEL_CLS = CommandReply
 
-    saga_manager: MinosSagaManager = Provide["saga_manager"]
-
-    def __init__(self, saga_manager: MinosSagaManager = None, **kwargs: Any):
+    @inject
+    def __init__(self, saga_manager: MinosSagaManager = Provide["saga_manager"], **kwargs: Any):
         super().__init__(**kwargs)
 
-        if saga_manager is not None:
-            self.saga_manager = saga_manager
+        self.saga_manager = saga_manager
 
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> CommandReplyHandler:
         handlers = {f"{config.service.name}Reply": None}
+        # noinspection PyProtectedMember
         return cls(*args, handlers=handlers, **config.broker.queue._asdict(), **kwargs)
 
-    async def dispatch_one(self, entry: HandlerEntry[CommandReply]) -> NoReturn:
+    async def dispatch_one(self, entry: HandlerEntry[CommandReply]) -> None:
         """Dispatch one row.
 
         :param entry: Entry to be dispatched.
